@@ -54,14 +54,87 @@ class FirestoreAdminAsyncClient:
     DEFAULT_ENDPOINT = FirestoreAdminClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = FirestoreAdminClient.DEFAULT_MTLS_ENDPOINT
 
+    collection_group_path = staticmethod(FirestoreAdminClient.collection_group_path)
+    parse_collection_group_path = staticmethod(
+        FirestoreAdminClient.parse_collection_group_path
+    )
+    database_path = staticmethod(FirestoreAdminClient.database_path)
+    parse_database_path = staticmethod(FirestoreAdminClient.parse_database_path)
     field_path = staticmethod(FirestoreAdminClient.field_path)
     parse_field_path = staticmethod(FirestoreAdminClient.parse_field_path)
     index_path = staticmethod(FirestoreAdminClient.index_path)
     parse_index_path = staticmethod(FirestoreAdminClient.parse_index_path)
 
-    from_service_account_file = FirestoreAdminClient.from_service_account_file
+    common_billing_account_path = staticmethod(
+        FirestoreAdminClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        FirestoreAdminClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(FirestoreAdminClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        FirestoreAdminClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        FirestoreAdminClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        FirestoreAdminClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(FirestoreAdminClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        FirestoreAdminClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(FirestoreAdminClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        FirestoreAdminClient.parse_common_location_path
+    )
+
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            FirestoreAdminAsyncClient: The constructed client.
+        """
+        return FirestoreAdminClient.from_service_account_info.__func__(FirestoreAdminAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            FirestoreAdminAsyncClient: The constructed client.
+        """
+        return FirestoreAdminClient.from_service_account_file.__func__(FirestoreAdminAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> FirestoreAdminTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            FirestoreAdminTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(FirestoreAdminClient).get_transport_class, type(FirestoreAdminClient)
     )
@@ -131,18 +204,20 @@ class FirestoreAdminAsyncClient:
         [IndexOperationMetadata][google.firestore.admin.v1.IndexOperationMetadata].
 
         Args:
-            request (:class:`~.firestore_admin.CreateIndexRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.CreateIndexRequest`):
                 The request object. The request for
                 [FirestoreAdmin.CreateIndex][google.firestore.admin.v1.FirestoreAdmin.CreateIndex].
             parent (:class:`str`):
                 Required. A parent name of the form
                 ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            index (:class:`~.gfa_index.Index`):
+            index (:class:`google.cloud.firestore_admin_v1.types.Index`):
                 Required. The composite index to
                 create.
+
                 This corresponds to the ``index`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -154,19 +229,18 @@ class FirestoreAdminAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.gfa_index.Index``: Cloud Firestore indexes
-                enable simple and complex queries against documents in a
-                database.
+                The result type for the operation will be :class:`google.cloud.firestore_admin_v1.types.Index` Cloud Firestore indexes enable simple and complex queries against
+                   documents in a database.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent, index]):
+        has_flattened_params = any([parent, index])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -222,12 +296,13 @@ class FirestoreAdminAsyncClient:
         r"""Lists composite indexes.
 
         Args:
-            request (:class:`~.firestore_admin.ListIndexesRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.ListIndexesRequest`):
                 The request object. The request for
                 [FirestoreAdmin.ListIndexes][google.firestore.admin.v1.FirestoreAdmin.ListIndexes].
             parent (:class:`str`):
                 Required. A parent name of the form
                 ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -239,7 +314,7 @@ class FirestoreAdminAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListIndexesAsyncPager:
+            google.cloud.firestore_admin_v1.services.firestore_admin.pagers.ListIndexesAsyncPager:
                 The response for
                 [FirestoreAdmin.ListIndexes][google.firestore.admin.v1.FirestoreAdmin.ListIndexes].
 
@@ -250,7 +325,8 @@ class FirestoreAdminAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -277,6 +353,7 @@ class FirestoreAdminAsyncClient:
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -312,12 +389,13 @@ class FirestoreAdminAsyncClient:
         r"""Gets a composite index.
 
         Args:
-            request (:class:`~.firestore_admin.GetIndexRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.GetIndexRequest`):
                 The request object. The request for
                 [FirestoreAdmin.GetIndex][google.firestore.admin.v1.FirestoreAdmin.GetIndex].
             name (:class:`str`):
                 Required. A name of the form
                 ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/indexes/{index_id}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -329,7 +407,7 @@ class FirestoreAdminAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.index.Index:
+            google.cloud.firestore_admin_v1.types.Index:
                 Cloud Firestore indexes enable simple
                 and complex queries against documents in
                 a database.
@@ -338,7 +416,8 @@ class FirestoreAdminAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -365,6 +444,7 @@ class FirestoreAdminAsyncClient:
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -394,12 +474,13 @@ class FirestoreAdminAsyncClient:
         r"""Deletes a composite index.
 
         Args:
-            request (:class:`~.firestore_admin.DeleteIndexRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.DeleteIndexRequest`):
                 The request object. The request for
                 [FirestoreAdmin.DeleteIndex][google.firestore.admin.v1.FirestoreAdmin.DeleteIndex].
             name (:class:`str`):
                 Required. A name of the form
                 ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/indexes/{index_id}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -413,7 +494,8 @@ class FirestoreAdminAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -440,6 +522,7 @@ class FirestoreAdminAsyncClient:
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -468,12 +551,13 @@ class FirestoreAdminAsyncClient:
         r"""Gets the metadata and configuration for a Field.
 
         Args:
-            request (:class:`~.firestore_admin.GetFieldRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.GetFieldRequest`):
                 The request object. The request for
                 [FirestoreAdmin.GetField][google.firestore.admin.v1.FirestoreAdmin.GetField].
             name (:class:`str`):
                 Required. A name of the form
                 ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/fields/{field_id}``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -485,7 +569,7 @@ class FirestoreAdminAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.field.Field:
+            google.cloud.firestore_admin_v1.types.Field:
                 Represents a single field in the
                 database.
                 Fields are grouped by their "Collection
@@ -496,7 +580,8 @@ class FirestoreAdminAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -523,6 +608,7 @@ class FirestoreAdminAsyncClient:
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -567,10 +653,10 @@ class FirestoreAdminAsyncClient:
         ``projects/{project_id}/databases/{database_id}/collectionGroups/__default__/fields/*``.
 
         Args:
-            request (:class:`~.firestore_admin.UpdateFieldRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.UpdateFieldRequest`):
                 The request object. The request for
                 [FirestoreAdmin.UpdateField][google.firestore.admin.v1.FirestoreAdmin.UpdateField].
-            field (:class:`~.gfa_field.Field`):
+            field (:class:`google.cloud.firestore_admin_v1.types.Field`):
                 Required. The field to be updated.
                 This corresponds to the ``field`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -583,22 +669,23 @@ class FirestoreAdminAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.gfa_field.Field``: Represents a single field
-                in the database.
+                :class:`google.cloud.firestore_admin_v1.types.Field`
+                Represents a single field in the database.
 
-                Fields are grouped by their "Collection Group", which
-                represent all collections in the database with the same
-                id.
+                   Fields are grouped by their "Collection Group", which
+                   represent all collections in the database with the
+                   same id.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([field]):
+        has_flattened_params = any([field])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -661,12 +748,13 @@ class FirestoreAdminAsyncClient:
         with the filter set to ``indexConfig.usesAncestorConfig:false``.
 
         Args:
-            request (:class:`~.firestore_admin.ListFieldsRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.ListFieldsRequest`):
                 The request object. The request for
                 [FirestoreAdmin.ListFields][google.firestore.admin.v1.FirestoreAdmin.ListFields].
             parent (:class:`str`):
                 Required. A parent name of the form
                 ``projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -678,7 +766,7 @@ class FirestoreAdminAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListFieldsAsyncPager:
+            google.cloud.firestore_admin_v1.services.firestore_admin.pagers.ListFieldsAsyncPager:
                 The response for
                 [FirestoreAdmin.ListFields][google.firestore.admin.v1.FirestoreAdmin.ListFields].
 
@@ -689,7 +777,8 @@ class FirestoreAdminAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -716,6 +805,7 @@ class FirestoreAdminAsyncClient:
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -760,12 +850,13 @@ class FirestoreAdminAsyncClient:
         Google Cloud Storage.
 
         Args:
-            request (:class:`~.firestore_admin.ExportDocumentsRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.ExportDocumentsRequest`):
                 The request object. The request for
                 [FirestoreAdmin.ExportDocuments][google.firestore.admin.v1.FirestoreAdmin.ExportDocuments].
             name (:class:`str`):
                 Required. Database to export. Should be of the form:
                 ``projects/{project_id}/databases/{database_id}``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -777,11 +868,11 @@ class FirestoreAdminAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:``~.gfa_operation.ExportDocumentsResponse``:
+                :class:`google.cloud.firestore_admin_v1.types.ExportDocumentsResponse`
                 Returned in the
                 [google.longrunning.Operation][google.longrunning.Operation]
                 response field.
@@ -790,7 +881,8 @@ class FirestoreAdminAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -850,12 +942,13 @@ class FirestoreAdminAsyncClient:
         already been imported to Cloud Firestore.
 
         Args:
-            request (:class:`~.firestore_admin.ImportDocumentsRequest`):
+            request (:class:`google.cloud.firestore_admin_v1.types.ImportDocumentsRequest`):
                 The request object. The request for
                 [FirestoreAdmin.ImportDocuments][google.firestore.admin.v1.FirestoreAdmin.ImportDocuments].
             name (:class:`str`):
                 Required. Database to import into. Should be of the
                 form: ``projects/{project_id}/databases/{database_id}``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -867,30 +960,29 @@ class FirestoreAdminAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.operation_async.AsyncOperation:
+            google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be
-                :class:``~.empty.Empty``: A generic empty message that
-                you can re-use to avoid defining duplicated empty
-                messages in your APIs. A typical example is to use it as
-                the request or the response type of an API method. For
-                instance:
+                The result type for the operation will be :class:`google.protobuf.empty_pb2.Empty` A generic empty message that you can re-use to avoid defining duplicated
+                   empty messages in your APIs. A typical example is to
+                   use it as the request or the response type of an API
+                   method. For instance:
 
-                ::
+                      service Foo {
+                         rpc Bar(google.protobuf.Empty) returns
+                         (google.protobuf.Empty);
 
-                    service Foo {
-                      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);
-                    }
+                      }
 
-                The JSON representation for ``Empty`` is empty JSON
-                object ``{}``.
+                   The JSON representation for Empty is empty JSON
+                   object {}.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
