@@ -15,51 +15,52 @@
 # limitations under the License.
 #
 
-from .index import Index
 from .field import Field
 from .firestore_admin import (
     CreateIndexRequest,
-    ListIndexesRequest,
-    ListIndexesResponse,
-    GetIndexRequest,
     DeleteIndexRequest,
-    UpdateFieldRequest,
+    ExportDocumentsRequest,
     GetFieldRequest,
+    GetIndexRequest,
+    ImportDocumentsRequest,
     ListFieldsRequest,
     ListFieldsResponse,
-    ExportDocumentsRequest,
-    ImportDocumentsRequest,
+    ListIndexesRequest,
+    ListIndexesResponse,
+    UpdateFieldRequest,
 )
+from .index import Index
 from .location import LocationMetadata
 from .operation import (
-    IndexOperationMetadata,
-    FieldOperationMetadata,
     ExportDocumentsMetadata,
-    ImportDocumentsMetadata,
     ExportDocumentsResponse,
+    FieldOperationMetadata,
+    ImportDocumentsMetadata,
+    IndexOperationMetadata,
     Progress,
+    OperationState,
 )
 
-
 __all__ = (
-    "Index",
     "Field",
     "CreateIndexRequest",
-    "ListIndexesRequest",
-    "ListIndexesResponse",
-    "GetIndexRequest",
     "DeleteIndexRequest",
-    "UpdateFieldRequest",
+    "ExportDocumentsRequest",
     "GetFieldRequest",
+    "GetIndexRequest",
+    "ImportDocumentsRequest",
     "ListFieldsRequest",
     "ListFieldsResponse",
-    "ExportDocumentsRequest",
-    "ImportDocumentsRequest",
+    "ListIndexesRequest",
+    "ListIndexesResponse",
+    "UpdateFieldRequest",
+    "Index",
     "LocationMetadata",
-    "IndexOperationMetadata",
-    "FieldOperationMetadata",
     "ExportDocumentsMetadata",
-    "ImportDocumentsMetadata",
     "ExportDocumentsResponse",
+    "FieldOperationMetadata",
+    "ImportDocumentsMetadata",
+    "IndexOperationMetadata",
     "Progress",
+    "OperationState",
 )
