@@ -148,7 +148,7 @@ class BaseClient(ClientWithProject):
             # We need this in order to set appropriate keepalive options.
 
             if self._emulator_host is not None:
-                channel = grpc.insecure_channel(self._emulator_host)
+                channel = self._emulator_channel(transport)
             else:
                 channel = transport.create_channel(
                     self._target,
@@ -165,6 +165,53 @@ class BaseClient(ClientWithProject):
 
         return self._firestore_api_internal
 
+    def _emulator_channel(self, transport):
+        """
+        Creates a channel using self._credentials in a similar way to grpc.secure_channel but
+        using grpc.local_channel_credentials() rather than grpc.ssh_channel_credentials() to allow easy connection
+        to a local firestore emulator. This allows local testing of firestore rules if the credentials have been
+        created from a signed custom token.
+
+        :return: grpc.Channel or grpc.aio.Channel
+        """
+        # TODO: Implement a special credentials type for emulator and use
+        # "transport.create_channel" to create gRPC channels once google-auth
+        # extends it's allowed credentials types.
+        if "GrpcAsyncIOTransport" in str(transport.__name__):
+            return grpc.aio.secure_channel(
+                self._emulator_host, self._local_composite_credentials()
+            )
+        else:
+            return grpc.secure_channel(
+                self._emulator_host, self._local_composite_credentials()
+            )
+
+    def _local_composite_credentials(self):
+        """
+        Creates the credentials for the local emulator channel
+        :return: grpc.ChannelCredentials
+        """
+        credentials = google.auth.credentials.with_scopes_if_required(
+            self._credentials, None
+        )
+        request = google.auth.transport.requests.Request()
+
+        # Create the metadata plugin for inserting the authorization header.
+        metadata_plugin = google.auth.transport.grpc.AuthMetadataPlugin(
+            credentials, request
+        )
+
+        # Create a set of grpc.CallCredentials using the metadata plugin.
+        google_auth_credentials = grpc.metadata_call_credentials(metadata_plugin)
+
+        # Using the local_credentials to allow connection to emulator
+        local_credentials = grpc.local_channel_credentials()
+
+        # Combine the local credentials and the authorization credentials.
+        return grpc.composite_channel_credentials(
+            local_credentials, google_auth_credentials
+        )
+
     def _target_helper(self, client_class) -> str:
         """Return the target (where the API is).
         Eg. "firestore.googleapis.com"
@@ -272,7 +319,7 @@ class BaseClient(ClientWithProject):
         return joined_path.split(_helpers.DOCUMENT_PATH_DELIMITER)
 
     @staticmethod
-    def field_path(*field_names: Tuple[str]) -> str:
+    def field_path(*field_names: str) -> str:
         """Create a **field path** from a list of nested field names.
 
         A **field path** is a ``.``-delimited concatenation of the field
@@ -293,7 +340,7 @@ class BaseClient(ClientWithProject):
         ``data['aa']['bb']['cc']``.
 
         Args:
-            field_names (Tuple[str, ...]): The list of field names.
+            field_names: The list of field names.
 
         Returns:
             str: The ``.``-delimited field path.
