@@ -18,7 +18,16 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, AsyncIterable, AsyncIterator, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    AsyncIterable,
+    Awaitable,
+    AsyncIterator,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
@@ -59,9 +68,70 @@ class FirestoreAsyncClient:
     DEFAULT_ENDPOINT = FirestoreClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = FirestoreClient.DEFAULT_MTLS_ENDPOINT
 
-    from_service_account_file = FirestoreClient.from_service_account_file
+    common_billing_account_path = staticmethod(
+        FirestoreClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        FirestoreClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(FirestoreClient.common_folder_path)
+    parse_common_folder_path = staticmethod(FirestoreClient.parse_common_folder_path)
+
+    common_organization_path = staticmethod(FirestoreClient.common_organization_path)
+    parse_common_organization_path = staticmethod(
+        FirestoreClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(FirestoreClient.common_project_path)
+    parse_common_project_path = staticmethod(FirestoreClient.parse_common_project_path)
+
+    common_location_path = staticmethod(FirestoreClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        FirestoreClient.parse_common_location_path
+    )
+
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            FirestoreAsyncClient: The constructed client.
+        """
+        return FirestoreClient.from_service_account_info.__func__(FirestoreAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            FirestoreAsyncClient: The constructed client.
+        """
+        return FirestoreClient.from_service_account_file.__func__(FirestoreAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> FirestoreTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            FirestoreTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(FirestoreClient).get_transport_class, type(FirestoreClient)
     )
@@ -125,7 +195,7 @@ class FirestoreAsyncClient:
         r"""Gets a single document.
 
         Args:
-            request (:class:`~.firestore.GetDocumentRequest`):
+            request (:class:`google.cloud.firestore_v1.types.GetDocumentRequest`):
                 The request object. The request for
                 [Firestore.GetDocument][google.firestore.v1.Firestore.GetDocument].
 
@@ -136,7 +206,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.document.Document:
+            google.cloud.firestore_v1.types.Document:
                 A Firestore document.
                 Must not exceed 1 MiB - 4 bytes.
 
@@ -154,10 +224,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -186,7 +257,7 @@ class FirestoreAsyncClient:
         r"""Lists documents.
 
         Args:
-            request (:class:`~.firestore.ListDocumentsRequest`):
+            request (:class:`google.cloud.firestore_v1.types.ListDocumentsRequest`):
                 The request object. The request for
                 [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
 
@@ -197,7 +268,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListDocumentsAsyncPager:
+            google.cloud.firestore_v1.services.firestore.pagers.ListDocumentsAsyncPager:
                 The response for
                 [Firestore.ListDocuments][google.firestore.v1.Firestore.ListDocuments].
 
@@ -218,10 +289,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -258,17 +330,18 @@ class FirestoreAsyncClient:
         r"""Updates or inserts a document.
 
         Args:
-            request (:class:`~.firestore.UpdateDocumentRequest`):
+            request (:class:`google.cloud.firestore_v1.types.UpdateDocumentRequest`):
                 The request object. The request for
                 [Firestore.UpdateDocument][google.firestore.v1.Firestore.UpdateDocument].
-            document (:class:`~.gf_document.Document`):
+            document (:class:`google.cloud.firestore_v1.types.Document`):
                 Required. The updated document.
                 Creates the document if it does not
                 already exist.
+
                 This corresponds to the ``document`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            update_mask (:class:`~.common.DocumentMask`):
+            update_mask (:class:`google.cloud.firestore_v1.types.DocumentMask`):
                 The fields to update.
                 None of the field paths in the mask may
                 contain a reserved name.
@@ -278,6 +351,7 @@ class FirestoreAsyncClient:
                 Fields referenced in the mask, but not
                 present in the input document, are
                 deleted from the document on the server.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -289,7 +363,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.gf_document.Document:
+            google.cloud.firestore_v1.types.Document:
                 A Firestore document.
                 Must not exceed 1 MiB - 4 bytes.
 
@@ -297,7 +371,8 @@ class FirestoreAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([document, update_mask]):
+        has_flattened_params = any([document, update_mask])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -322,6 +397,7 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -353,13 +429,14 @@ class FirestoreAsyncClient:
         r"""Deletes a document.
 
         Args:
-            request (:class:`~.firestore.DeleteDocumentRequest`):
+            request (:class:`google.cloud.firestore_v1.types.DeleteDocumentRequest`):
                 The request object. The request for
                 [Firestore.DeleteDocument][google.firestore.v1.Firestore.DeleteDocument].
             name (:class:`str`):
                 Required. The resource name of the Document to delete.
                 In the format:
                 ``projects/{project_id}/databases/{database_id}/documents/{document_path}``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -373,7 +450,8 @@ class FirestoreAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -396,10 +474,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -423,13 +502,13 @@ class FirestoreAsyncClient:
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> AsyncIterable[firestore.BatchGetDocumentsResponse]:
+    ) -> Awaitable[AsyncIterable[firestore.BatchGetDocumentsResponse]]:
         r"""Gets multiple documents.
         Documents returned by this method are not guaranteed to
         be returned in the same order that they were requested.
 
         Args:
-            request (:class:`~.firestore.BatchGetDocumentsRequest`):
+            request (:class:`google.cloud.firestore_v1.types.BatchGetDocumentsRequest`):
                 The request object. The request for
                 [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
 
@@ -440,7 +519,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            AsyncIterable[~.firestore.BatchGetDocumentsResponse]:
+            AsyncIterable[google.cloud.firestore_v1.types.BatchGetDocumentsResponse]:
                 The streamed response for
                 [Firestore.BatchGetDocuments][google.firestore.v1.Firestore.BatchGetDocuments].
 
@@ -458,10 +537,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=300.0,
             ),
             default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -491,12 +571,13 @@ class FirestoreAsyncClient:
         r"""Starts a new transaction.
 
         Args:
-            request (:class:`~.firestore.BeginTransactionRequest`):
+            request (:class:`google.cloud.firestore_v1.types.BeginTransactionRequest`):
                 The request object. The request for
                 [Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction].
             database (:class:`str`):
                 Required. The database name. In the format:
                 ``projects/{project_id}/databases/{database_id}``.
+
                 This corresponds to the ``database`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -508,7 +589,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.firestore.BeginTransactionResponse:
+            google.cloud.firestore_v1.types.BeginTransactionResponse:
                 The response for
                 [Firestore.BeginTransaction][google.firestore.v1.Firestore.BeginTransaction].
 
@@ -516,7 +597,8 @@ class FirestoreAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([database]):
+        has_flattened_params = any([database])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -539,10 +621,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -574,18 +657,20 @@ class FirestoreAsyncClient:
         documents.
 
         Args:
-            request (:class:`~.firestore.CommitRequest`):
+            request (:class:`google.cloud.firestore_v1.types.CommitRequest`):
                 The request object. The request for
                 [Firestore.Commit][google.firestore.v1.Firestore.Commit].
             database (:class:`str`):
                 Required. The database name. In the format:
                 ``projects/{project_id}/databases/{database_id}``.
+
                 This corresponds to the ``database`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            writes (:class:`Sequence[~.gf_write.Write]`):
+            writes (:class:`Sequence[google.cloud.firestore_v1.types.Write]`):
                 The writes to apply.
                 Always executed atomically and in order.
+
                 This corresponds to the ``writes`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -597,7 +682,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.firestore.CommitResponse:
+            google.cloud.firestore_v1.types.CommitResponse:
                 The response for
                 [Firestore.Commit][google.firestore.v1.Firestore.Commit].
 
@@ -605,7 +690,8 @@ class FirestoreAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([database, writes]):
+        has_flattened_params = any([database, writes])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -618,8 +704,9 @@ class FirestoreAsyncClient:
 
         if database is not None:
             request.database = database
-        if writes is not None:
-            request.writes = writes
+
+        if writes:
+            request.writes.extend(writes)
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -630,6 +717,7 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -660,18 +748,20 @@ class FirestoreAsyncClient:
         r"""Rolls back a transaction.
 
         Args:
-            request (:class:`~.firestore.RollbackRequest`):
+            request (:class:`google.cloud.firestore_v1.types.RollbackRequest`):
                 The request object. The request for
                 [Firestore.Rollback][google.firestore.v1.Firestore.Rollback].
             database (:class:`str`):
                 Required. The database name. In the format:
                 ``projects/{project_id}/databases/{database_id}``.
+
                 This corresponds to the ``database`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             transaction (:class:`bytes`):
                 Required. The transaction to roll
                 back.
+
                 This corresponds to the ``transaction`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -685,7 +775,8 @@ class FirestoreAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([database, transaction]):
+        has_flattened_params = any([database, transaction])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -710,10 +801,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -737,11 +829,11 @@ class FirestoreAsyncClient:
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> AsyncIterable[firestore.RunQueryResponse]:
+    ) -> Awaitable[AsyncIterable[firestore.RunQueryResponse]]:
         r"""Runs a query.
 
         Args:
-            request (:class:`~.firestore.RunQueryRequest`):
+            request (:class:`google.cloud.firestore_v1.types.RunQueryRequest`):
                 The request object. The request for
                 [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
 
@@ -752,7 +844,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            AsyncIterable[~.firestore.RunQueryResponse]:
+            AsyncIterable[google.cloud.firestore_v1.types.RunQueryResponse]:
                 The response for
                 [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
 
@@ -770,10 +862,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=300.0,
             ),
             default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -806,7 +899,7 @@ class FirestoreAsyncClient:
         results.
 
         Args:
-            request (:class:`~.firestore.PartitionQueryRequest`):
+            request (:class:`google.cloud.firestore_v1.types.PartitionQueryRequest`):
                 The request object. The request for
                 [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
 
@@ -817,7 +910,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.PartitionQueryAsyncPager:
+            google.cloud.firestore_v1.services.firestore.pagers.PartitionQueryAsyncPager:
                 The response for
                 [Firestore.PartitionQuery][google.firestore.v1.Firestore.PartitionQuery].
 
@@ -838,10 +931,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=300.0,
             ),
             default_timeout=300.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -872,12 +966,12 @@ class FirestoreAsyncClient:
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> AsyncIterable[firestore.WriteResponse]:
+    ) -> Awaitable[AsyncIterable[firestore.WriteResponse]]:
         r"""Streams batches of document updates and deletes, in
         order.
 
         Args:
-            requests (AsyncIterator[`~.firestore.WriteRequest`]):
+            requests (AsyncIterator[`google.cloud.firestore_v1.types.WriteRequest`]):
                 The request object AsyncIterator. The request for
                 [Firestore.Write][google.firestore.v1.Firestore.Write].
                 The first request creates a stream, or resumes an
@@ -897,7 +991,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            AsyncIterable[~.firestore.WriteResponse]:
+            AsyncIterable[google.cloud.firestore_v1.types.WriteResponse]:
                 The response for
                 [Firestore.Write][google.firestore.v1.Firestore.Write].
 
@@ -928,11 +1022,11 @@ class FirestoreAsyncClient:
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> AsyncIterable[firestore.ListenResponse]:
+    ) -> Awaitable[AsyncIterable[firestore.ListenResponse]]:
         r"""Listens to changes.
 
         Args:
-            requests (AsyncIterator[`~.firestore.ListenRequest`]):
+            requests (AsyncIterator[`google.cloud.firestore_v1.types.ListenRequest`]):
                 The request object AsyncIterator. A request for
                 [Firestore.Listen][google.firestore.v1.Firestore.Listen]
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -942,7 +1036,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            AsyncIterable[~.firestore.ListenResponse]:
+            AsyncIterable[google.cloud.firestore_v1.types.ListenResponse]:
                 The response for
                 [Firestore.Listen][google.firestore.v1.Firestore.Listen].
 
@@ -957,10 +1051,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=86400.0,
             ),
             default_timeout=86400.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -988,7 +1083,7 @@ class FirestoreAsyncClient:
         r"""Lists all the collection IDs underneath a document.
 
         Args:
-            request (:class:`~.firestore.ListCollectionIdsRequest`):
+            request (:class:`google.cloud.firestore_v1.types.ListCollectionIdsRequest`):
                 The request object. The request for
                 [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
             parent (:class:`str`):
@@ -996,6 +1091,7 @@ class FirestoreAsyncClient:
                 ``projects/{project_id}/databases/{database_id}/documents/{document_path}``.
                 For example:
                 ``projects/my-project/databases/my-database/documents/chatrooms/my-chatroom``
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -1007,7 +1103,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListCollectionIdsAsyncPager:
+            google.cloud.firestore_v1.services.firestore.pagers.ListCollectionIdsAsyncPager:
                 The response from
                 [Firestore.ListCollectionIds][google.firestore.v1.Firestore.ListCollectionIds].
 
@@ -1018,7 +1114,8 @@ class FirestoreAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -1041,10 +1138,11 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
+                    exceptions.DeadlineExceeded,
                     exceptions.InternalServerError,
                     exceptions.ServiceUnavailable,
-                    exceptions.DeadlineExceeded,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -1089,7 +1187,7 @@ class FirestoreAsyncClient:
         [Commit][google.firestore.v1.Firestore.Commit] instead.
 
         Args:
-            request (:class:`~.firestore.BatchWriteRequest`):
+            request (:class:`google.cloud.firestore_v1.types.BatchWriteRequest`):
                 The request object. The request for
                 [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
 
@@ -1100,7 +1198,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.firestore.BatchWriteResponse:
+            google.cloud.firestore_v1.types.BatchWriteResponse:
                 The response from
                 [Firestore.BatchWrite][google.firestore.v1.Firestore.BatchWrite].
 
@@ -1120,6 +1218,7 @@ class FirestoreAsyncClient:
                 predicate=retries.if_exception_type(
                     exceptions.Aborted, exceptions.ServiceUnavailable,
                 ),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
@@ -1148,7 +1247,7 @@ class FirestoreAsyncClient:
         r"""Creates a new document.
 
         Args:
-            request (:class:`~.firestore.CreateDocumentRequest`):
+            request (:class:`google.cloud.firestore_v1.types.CreateDocumentRequest`):
                 The request object. The request for
                 [Firestore.CreateDocument][google.firestore.v1.Firestore.CreateDocument].
 
@@ -1159,7 +1258,7 @@ class FirestoreAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.document.Document:
+            google.cloud.firestore_v1.types.Document:
                 A Firestore document.
                 Must not exceed 1 MiB - 4 bytes.
 
@@ -1177,6 +1276,7 @@ class FirestoreAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                deadline=60.0,
             ),
             default_timeout=60.0,
             client_info=DEFAULT_CLIENT_INFO,
