@@ -73,10 +73,10 @@ class FirestoreTransport(abc.ABC):
             scope (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
@@ -84,6 +84,9 @@ class FirestoreTransport(abc.ABC):
             host += ":443"
         self._host = host
 
+        # Save the scopes.
+        self._scopes = scopes or self.AUTH_SCOPES
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
@@ -93,20 +96,17 @@ class FirestoreTransport(abc.ABC):
 
         if credentials_file is not None:
             credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=scopes, quota_project_id=quota_project_id
+                credentials_file, scopes=self._scopes, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
             credentials, _ = auth.default(
-                scopes=scopes, quota_project_id=quota_project_id
+                scopes=self._scopes, quota_project_id=quota_project_id
             )
 
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages(client_info)
-
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -117,10 +117,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -132,10 +133,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -147,6 +149,7 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -158,10 +161,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -173,10 +177,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=300.0,
                 ),
                 default_timeout=300.0,
                 client_info=client_info,
@@ -188,10 +193,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -203,6 +209,7 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -214,10 +221,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -229,10 +237,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=300.0,
                 ),
                 default_timeout=300.0,
                 client_info=client_info,
@@ -244,10 +253,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=300.0,
                 ),
                 default_timeout=300.0,
                 client_info=client_info,
@@ -262,10 +272,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=86400.0,
                 ),
                 default_timeout=86400.0,
                 client_info=client_info,
@@ -277,10 +288,11 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
+                        exceptions.DeadlineExceeded,
                         exceptions.InternalServerError,
                         exceptions.ServiceUnavailable,
-                        exceptions.DeadlineExceeded,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -294,6 +306,7 @@ class FirestoreTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.Aborted, exceptions.ServiceUnavailable,
                     ),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
@@ -305,6 +318,7 @@ class FirestoreTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
+                    deadline=60.0,
                 ),
                 default_timeout=60.0,
                 client_info=client_info,
